@@ -11,23 +11,19 @@ if test -z "$*"; then
         "--none for defaults, or --full for all" >&2
     exit 1
 elif test "$*" = "--help" || test "$*" = "-h"; then
-    ./configure --help
+    echo "build.sh: Please specify configure options," \
+        "--none for defaults, or --full for all" >&2
     exit 1
 fi
 
-./autogen.sh
-
 if test "$*" = "--none"; then
-    ./configure
+    cmake . -DUSE_GSL=
+elif test "$*" = "--common"; then
+    cmake . -DUSE_GSL=1 -DUSE_PCAP=1 -DUSE_SSL= -DUSE_SCTP=
 elif test "$*" = "--full"; then
-    ./configure \
-        --with-gsl \
-        --with-openssl \
-        --with-pcap \
-        --with-rtpstream \
-        --with-sctp
+    cmake . -DUSE_GSL=1 -DUSE_PCAP=1 -DUSE_SSL=1 -DUSE_SCTP=1
 else
-    ./configure "$@"
+    cmake . "$@"
 fi
 
 # For git checkout, run unit tests.
