@@ -21,11 +21,6 @@
 #ifndef __SIPP_STRINGS_H__
 #define __SIPP_STRINGS_H__
 
-#include <cstddef>
-
-char *strcasestr2 (char *__haystack, const char *__needle);
-char *strncasestr (char *s, const char *find, size_t n);
-void init_tolower_table();
 int get_decimal_from_hex(char hex);
 void get_host_and_port(const char *addr, char *host, int *port);
 void trim(char *s);
