@@ -28,7 +28,8 @@ int xp_set_xml_buffer_from_string(const char *str);
 int xp_set_xml_buffer_from_file(const char *filename);
 char* xp_open_element(int index);
 void xp_close_element(void);
-char* xp_get_value(const char *name);
+int xp_is_invalid();
+const char* xp_get_value(const char *name);
 char* xp_get_cdata(void);
 int xp_get_content_length(const char *P_buffer);
 
